"""
Simple, no configuration site generator module
"""

def generate(src_dir, dst_dir):
    print("Source dir `%s`" % src_dir)
    print("Destination dir `%s`" % dst_dir)

    # TODO: generate HTML for every .md file in src_dir and
    # place them in dst_dir
